@@ -416,6 +416,8 @@ class PySob:
 
     @staticmethod
     def count(errors: list[str] = None,
+              where_clause: str = None,
+              where_vals: tuple = None,
               where_data: dict[str, Any] = None,
               db_engine: DbEngine = None,
               db_conn: Any = None,
@@ -435,6 +437,8 @@ class PySob:
             name: str = f"{cls.__module__}.{cls.__qualname__}"
             result = db_count(errors=errors,
                               table=sob_db_specs[name][0],
+                              where_clause=where_clause,
+                              where_vals=where_vals,
                               where_data=where_data,
                               engine=db_engine,
                               connection=db_conn,
